@@ -248,7 +248,11 @@ class MTCNN(nn.Module):
 
         # Determine if a batch or single image was passed
         batch_mode = True
-        if not isinstance(img, (list, tuple)) and not (isinstance(img, np.ndarray) and len(img.shape) == 4):
+        if (
+            not isinstance(img, (list, tuple)) and
+            not (isinstance(img, np.ndarray) and len(img.shape) == 4) and
+            not (isinstance(img, torch.Tensor) and len(img.shape) == 4)
+        ):
             img = [img]
             batch_boxes = [batch_boxes]
             batch_probs = [batch_probs]
@@ -373,7 +377,11 @@ class MTCNN(nn.Module):
         probs = np.array(probs)
         points = np.array(points)
 
-        if not isinstance(img, (list, tuple)) and not (isinstance(img, np.ndarray) and len(img.shape) == 4):
+        if (
+            not isinstance(img, (list, tuple)) and 
+            not (isinstance(img, np.ndarray) and len(img.shape) == 4) and
+            not (isinstance(img, torch.Tensor) and len(img.shape) == 4)
+        ):
             boxes = boxes[0]
             probs = probs[0]
             points = points[0]
@@ -388,6 +396,7 @@ def fixed_image_standardization(image_tensor):
     processed_tensor = (image_tensor - 127.5) / 128.0
     return processed_tensor
 
+
 def prewhiten(x):
     mean = x.mean()
     std = x.std()
